pub enum StringKey {
Num(u32),
Name(String),
}Expand description
A key in a language file.
A key may be either a nonnegative integer or an arbitrary string.
The original game supports only nonnegative integers. The HD Edition allows for integers as well as Strings to serve as keys in a key value file.
Variants
Num(u32)
An integer string key.
Name(String)
A named string key.
The string must not represent a u32 value (such keys must be Num).
Implementations